==> webkit2gtk_2.51.3.orig.tar.xz: webkitgtk-2.51.3/Source/WebCore/dom/FragmentDirectiveUtilities.cpp <==
/*
 * Copyright (C) 2022-2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "FragmentDirectiveUtilities.h"

#include "NodeDocument.h"
#include "NodeRenderStyle.h"
#include "NodeTraversal.h"
#include "RenderStyleInlines.h"
#include <wtf/text/TextStream.h>

namespace WebCore {

TextStream& operator<<(TextStream& ts, const ParsedTextDirective& directive)
{
    ts << "ParsedTextDirective [";
    if (!directive.prefix.isEmpty())
        ts << "prefix: " << directive.prefix << "; ";
    if (!directive.startText.isEmpty())
        ts << "startText: " << directive.startText << "; ";
    if (!directive.endText.isEmpty())
        ts << "endText: " << directive.endText << "; ";
    if (!directive.suffix.isEmpty())
        ts << "suffix: " << directive.suffix << "; ";
    ts << "]";
    return ts;
}

namespace FragmentDirectiveUtilities {

// https://wicg.github.io/scroll-to-text-fragment/#nearest-block-ancestor
ContainerNode& nearestBlockAncestor(Node& node)
{
    for (RefPtr currentNode = node; currentNode; currentNode = currentNode->parentNode()) {
        if (CheckedPtr renderElement = dynamicDowncast<RenderElement>(currentNode->renderer()); renderElement && renderElement->style().isDisplayBlockLevel())
            return downcast<ContainerNode>(*currentNode);
    }
    return node.document();
}

} // namespace FragmentDirectiveUtilities

} // WebCore

==> webkit2gtk_2.51.90.orig.tar.xz: webkitgtk-2.51.90/Source/WebCore/dom/FragmentDirectiveUtilities.cpp <==
/*
 * Copyright (C) 2022-2024 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "FragmentDirectiveUtilities.h"

#include "NodeDocument.h"
#include "NodeRenderStyle.h"
#include "NodeTraversal.h"
#include "RenderStyle+GettersInlines.h"
#include <wtf/text/TextStream.h>

namespace WebCore {

TextStream& operator<<(TextStream& ts, const ParsedTextDirective& directive)
{
    ts << "ParsedTextDirective [";
    if (!directive.prefix.isEmpty())
        ts << "prefix: " << directive.prefix << "; ";
    if (!directive.startText.isEmpty())
        ts << "startText: " << directive.startText << "; ";
    if (!directive.endText.isEmpty())
        ts << "endText: " << directive.endText << "; ";
    if (!directive.suffix.isEmpty())
        ts << "suffix: " << directive.suffix << "; ";
    ts << "]";
    return ts;
}

namespace FragmentDirectiveUtilities {

// https://wicg.github.io/scroll-to-text-fragment/#nearest-block-ancestor
ContainerNode& nearestBlockAncestor(Node& node)
{
    for (RefPtr currentNode = node; currentNode; currentNode = currentNode->parentNode()) {
        if (CheckedPtr renderElement = dynamicDowncast<RenderElement>(currentNode->renderer()); renderElement && renderElement->style().isDisplayBlockLevel())
            return downcast<ContainerNode>(*currentNode);
    }
    return node.document();
}

} // namespace FragmentDirectiveUtilities

} // WebCore
